==> hoteldruid-mod-de_1.3.2-1.tar.gz: de/crea_backup.php <==
<?php

switch ($messaggio) {

case "File creato":                                                      $messaggio = "Datei erzeugt"; break;
case "Non ho il permesso di scrittura sul file":                         $messaggio = "Keine Schreibberechtigung f&uuml;r diese Datei"; break;
case "Si è verificato un errore cancellando il file":                   $messaggio = "Fehler beim l&ouml;schen der Datei"; break;
case "File cancellato":                                                  $messaggio = "Datei gel&ouml;scht"; break;
case "<b style=\"color: red;\">ATTENZIONE</b>: premendo su <b>\"<i>Continua</i>\"</b>, prima di ripristinare i dati dal <i>file</i>, tutti i dati del <i>database attuale</i> verranno <b>cancellati</b>":        $messaggio = "<b style=\"color: red;\">Warnung</b>: Wenn Sie  <b>\"<i>CONTINUE</i>\"</b>whlen, werden alle  <i>Daten</i> Ihrer aktuellen Datenbank <b>gelscht!</b>"; break;
case "Inserisci i nuovi dati per la connessione al database":            $messaggio = "Neue Daten f&uuml;r die Datenbankverbindung eingeben"; break;
case "Tipo di database":                                                 $messaggio = "Datenbanktyp"; break;
case "Nome del database da utilizzare":                                  $messaggio = "Name der Datenbank"; break;
case "Database già esistente":                                          $messaggio = "Existierende Datenbank"; break;
case "Si":                                                               $messaggio = "Ja"; break;
case "No":                                                               $messaggio = "Nein"; break;
case "Se già esistente e non vuoto usare un prefisso non presente nel database per il nome delle tabelle":        $messaggio = "Wenn Sie bereits existiert und nicht leer ist benutze ein neues Prefix f&uuml;r die Tabellennamen in der Datenbank."; break;
case "Nome del computer a cui collegarsi":                               $messaggio = "Name des Rechners zu dem verbunden wird"; break;
case "Numero della porta a cui collegarsi":                              $messaggio = "Port Nummer f&uuml;r die Verbindung"; break;
case "Normalmete 5432 per Postgresql o 3306 per Mysql":                  $messaggio = "Normalerweise 5432 f&uuml;r Postgresql oder 3306 f&uuml;r MySQL"; break;
case "Nome per l'autenticazione al database":                            $messaggio = "Benutername f&uuml;r die Datenbank"; break;
case "Parola segreta per l'autenticazione al database":                  $messaggio = "Passwort f&uuml;r die Datenbank"; break;
case "Caricare la libreria dinamica \"pgsql.so\" o \"mysql.so\"":        $messaggio = "Dynamische Bibliothek \"pgsql.so\" oder \"mysql.so\" laden"; break;
case "scegliere si se non viene caricata automaticamente da php":        $messaggio = "Ja w&auml;hlen, wenn dies nicht automatisch durch PHP geschieht."; break;
case "Nome del database a cui collegarsi temporaneamente":               $messaggio = "Name der Datenbank f&uuml;r die tempor&auml;re Verbindung"; break;
case "solo per Postgresql con database non esistente":                   $messaggio = "nur f&uuml;r Postgresql, wenn keine Datenbank existiert"; break;
case "Continua":                                                         $messaggio = "Weiter"; break;
case "Vecchio database svuotato, per rimuoverlo del tutto procedere manualmente":        $messaggio = "Alte Datenbank geleert, sie kann nun komplett gel&ouml;scht werden"; break;
case "Database creato":                                                  $messaggio = "Datenbank erzeugt"; break;
case "Non è stato possibile connettersi al nuovo database, controllare i dati per la connessione, i privilegi dell' utente o il nome del database":        $messaggio = "Datenbankverbindung fehlgeschlagen, &uuml;berpr&uuml;fen Sie die Daten, die Benutzerrechte oder den Namen der Datenbank."; break;
case "Non è stato possibile creare il nuovo database, controllare i dati per la connessione, i privilegi dell' utente, il nome del database o se esiste già un database chiamato":        $messaggio = "Erzeugung der Datenbank fehlgeschlagen, &uuml;berpr&uuml;fen Sie die Daten, die Benutzerrechte oder den Namen der Datenbank oder ob eine Datenbank bereits existiert mit dem Namen"; break;
case "Non ho i permessi di scrittura sulla cartella dati":               $messaggio = "Keine Schreibrechte auf den dati Ordner"; break;
case "La versione attuale di hoteldruid e quella del file non coincidono":	$messaggio = "The current version of hoteldruid and the one of the file are not the same"; break;
case "Non ho potuto leggere il file":                                    $messaggio = "Lesen nicht m&ouml;glich von Datei"; break;
case "Torna indietro":                                                   $messaggio = "Zur&uuml;ck"; break;
case "Sistema di backup per hoteldruid":  	$messaggio = "Backup system for hoteldruid"; break;
case "Crea il file di backup":                                           $messaggio = "Sicherungsdatei erzeugen"; break;
case "Crea un nuovo file di backup":                                     $messaggio = "Neue Sicherungsdatei erzeugen"; break;
case "sovrascrivendo l'attuale":                                         $messaggio = "existierende &uuml;berschreiben"; break;
case "Guarda il file":                                                   $messaggio = "Zeige Datei"; break;
case "per salvarlo (eventualmente usa il bottone indietro del browser per tornare qui)":        $messaggio = "zur Sicherung ( nuten Sie den Browser \"zurck Button\" um zurckzugelangen"; break;
case "Cancella":                                                         $messaggio = "L&ouml;schen"; break;
case " l'attuale file di backup":                                        $messaggio = " aktuelle Datensicherungsdatei"; break;
case "Ripristina i dati dal file":                                       $messaggio = "Wiederherstellung der Daten von Datei"; break;
case " (i dati attuali verranno cancellati), utilizzando per la connessione al database:":        $messaggio = " (aktuelle Daten werden gel&ouml;scht), benutzen f&uuml;r Datenbankerzeugung:"; break;
case "i dati dell'attuale connessione":                                  $messaggio = "Daten der aktuellen Verbindung"; break;
case "nuovi dati":                                                       $messaggio = "neue Daten"; break;
case "Ho fatto l'upload del file":                                       $messaggio = "Sie haben die Datei hochgeladen"; break;
case "Non ho potuto fare l'upload del file":                             $messaggio = "Fehlschlag beim Hochladen der Datei"; break;
case "Fai l'upload":                                                     $messaggio = "Hochladen"; break;
case " del file di backup":                                              $messaggio = " diese Sicherungsdatei"; break;
case " di un nuovo file di backup":                                      $messaggio = " dieser neuen Sicherungsdatei"; break;
case "Prefisso nel nome delle tabelle":                                  $messaggio = "Prefix in Tabellenname"; break;
case "opzionale, utile per più installazioni di hoteldruid nello stesso database":	$messaggio = "optional, useful for more installations of hoteldruid in the same database"; break;
case "Il prefisso del nome delle tabelle è sbagliato (accettate solo lettere minuscole, numeri e _ , primo carattere lettera)":        $messaggio = "Das Prefix der Tabellennamen ist ung&uuml;ltig (nur Kleinbuchstaben, Nummern und _, das erste Zeichen mu&szlig; ein Buchstabe sein)"; break;
case "Il contenuto del file inviato non è corretto":                    $messaggio = "Der Inhalt der hochgeladenen Datei war fehlerhaft"; break;
case "Il formato del file è errato":                                    $messaggio = "Das Format der Datei war falsch"; break;
case "Compresso":                                                        $messaggio = "Komprimiert"; break;
case "Backup dei documenti":                                             $messaggio = "Dokumentensicherung"; break;
case "Crea il file di backup dei documenti":                             $messaggio = "Sicherung der Dokumente"; break;
case "Crea un nuovo file di backup dei documenti":                       $messaggio = "Erstellen einer neuen Dokumentensicherung"; break;
case " del file di backup dei documenti":                                $messaggio = " Backup dieser Dokumente"; break;
case " di un nuovo file di backup dei documenti":                        $messaggio = " neue Dokumente in diesem Backupsatz"; break;
case " l'attuale file di backup dei documenti":                          $messaggio = " aktuelle Dokumente in diesem Backupsatz"; break;
case "aggiungi ai documenti attuali":                                    $messaggio = "zum aktuellen Dokument hinzufgen"; break;
case "rimpiazza i documenti attuali":                                    $messaggio = "aktuelles Dokument ersetzen"; break;
case "i documenti attuali verranno cancellati":                          $messaggio = "aktuelles Dokument wird gelscht"; break;
case "Ripristina i documenti dal file":                                  $messaggio = "Dokument wiederherstellen"; break;
case "Documenti ripristinati":                                           $messaggio = "Documente wiederhergestellt"; break;
case "Backup completo":                                                  $messaggio = "Vollst&auml;ndige Sicherung"; break;
case "Includi i modelli internet":                                       $messaggio = "Vorlagen einschliessen"; break;
case "creato il":                                                        $messaggio = "erstellt"; break;
case "alle":                                                             $messaggio = "um"; break;
case "copia":                                                            $messaggio = "Kopie"; break;
case "il file di backup dai documenti predefiniti in":                   $messaggio = "Backupsatz der Standarddokumente aus"; break;
case "file copiato":                                                     $messaggio = "Dateine kopiert"; break;
case "si è verificato un errore copiando il file":                      $messaggio = "Es ist ein Fehler beim kopieren aufgetreten"; break;
case "Errori":  				$messaggio = "Errors"; break;
case "Includi tutti gli anni":  		$messaggio = "Include all years"; break;
case "Includi solo gli anni selezionati":  	$messaggio = "Include only selected years"; break;
case "Prova a mantenere i dati degli anni non contenuti nel backup":	$messaggio = "Try to retain data of years not contained in the backup"; break;
case "alcuni dati di questi anni potrebbero comunque venir persi":	$messaggio = "some data of these years may be lost anyway"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-de_2.1.2-1.tar.gz: de/crea_backup.php <==
<?php

switch ($messaggio) {

case "File creato":                                                      $messaggio = "Datei erzeugt"; break;
case "Non ho il permesso di scrittura sul file":                         $messaggio = "Keine Schreibberechtigung f&uuml;r diese Datei"; break;
case "Si è verificato un errore cancellando il file":                   $messaggio = "Fehler beim l&ouml;schen der Datei"; break;
case "File cancellato":                                                  $messaggio = "Datei gel&ouml;scht"; break;
case "<b style=\"color: red;\">ATTENZIONE</b>: premendo su <b>\"<i>Continua</i>\"</b>, prima di ripristinare i dati dal <i>file</i>, tutti i dati del <i>database attuale</i> verranno <b>cancellati</b>":     $messaggio = "<b style=\"color: red;\">Warnung</b>: Wenn Sie  <b>\"<i>CONTINUE</i>\"</b>whlen, werden alle  <i>Daten</i> Ihrer aktuellen Datenbank <b>gelscht!</b>"; break;
case "Inserisci i nuovi dati per la connessione al database":            $messaggio = "Neue Daten f&uuml;r die Datenbankverbindung eingeben"; break;
case "Tipo di database":                                                 $messaggio = "Datenbanktyp"; break;
case "Nome del database da utilizzare":                                  $messaggio = "Name der Datenbank"; break;
case "Database già esistente":                                          $messaggio = "Existierende Datenbank"; break;
case "Si":                                                               $messaggio = "Ja"; break;
case "No":                                                               $messaggio = "Nein"; break;
case "Se già esistente e non vuoto usare un prefisso non presente nel database per il nome delle tabelle":                                                                          $messaggio = "Wenn Sie bereits existiert und nicht leer ist benutze ein neues Prefix f&uuml;r die Tabellennamen in der Datenbank."; break;
case "Nome del computer a cui collegarsi":                               $messaggio = "Name des Rechners zu dem verbunden wird"; break;
case "Numero della porta a cui collegarsi":                              $messaggio = "Portnummer f&uuml;r die Verbindung"; break;
case "Nome per l'autenticazione al database":                            $messaggio = "Benutername f&uuml;r die Datenbank"; break;
case "Parola segreta per l'autenticazione al database":                  $messaggio = "Passwort f&uuml;r die Datenbank"; break;
case "Caricare la libreria dinamica \"pgsql.so\" o \"mysql.so\"":        $messaggio = "Dynamische Bibliothek \"pgsql.so\" oder \"mysql.so\" laden"; break;
case "scegliere si se non viene caricata automaticamente da php":        $messaggio = "Ja w&auml;hlen, wenn dies nicht automatisch durch PHP geschieht."; break;
case "Nome del database a cui collegarsi temporaneamente":               $messaggio = "Name der Datenbank f&uuml;r die tempor&auml;re Verbindung"; break;
case "solo per Postgresql con database non esistente":                   $messaggio = "nur f&uuml;r Postgresql, wenn keine Datenbank existiert"; break;
case "Continua":                                                         $messaggio = "Weiter"; break;
case "Vecchio database svuotato, per rimuoverlo del tutto procedere manualmente":                                                                          $messaggio = "Alte Datenbank geleert, sie kann nun komplett gel&ouml;scht werden"; break;
case "Database creato":                                                  $messaggio = "Datenbank erzeugt"; break;
case "Non è stato possibile connettersi al nuovo database, controllare i dati per la connessione, i privilegi dell' utente o il nome del database":                                                           $messaggio = "Datenbankverbindung fehlgeschlagen, &uuml;berpr&uuml;fen Sie die Daten, die Benutzerrechte oder den Namen der Datenbank."; break;
case "Non è stato possibile creare il nuovo database, controllare i dati per la connessione, i privilegi dell' utente, il nome del database o se esiste già un database chiamato":                           $messaggio = "Erzeugen der Datenbank fehlgeschlagen, &uuml;berpr&uuml;fen Sie die Daten, die Benutzerrechte oder den Namen der Datenbank oder ob eine Datenbank mit gleichem Namen bereits existiert"; break;
case "Non ho i permessi di scrittura sulla cartella dati":               $messaggio = "Keine Schreibrechte auf den dati Ordner"; break;
case "La versione attuale di hoteldruid e quella del file non coincidono":$messaggio = "Die aktuelle Version von Hoteldruid und die Version der Datei stimmen nicht &uuml;berein"; break;
case "Non ho potuto leggere il file":                                    $messaggio = "Lesen nicht m&ouml;glich von Datei"; break;
case "Torna indietro":                                                   $messaggio = "Zur&uuml;ck"; break;
case "Crea il file di backup":                                           $messaggio = "Sicherungsdatei erzeugen"; break;
case "Crea un nuovo file di backup":                                     $messaggio = "Neue Sicherungsdatei erzeugen"; break;
case "sovrascrivendo l'attuale":                                         $messaggio = "existierende &uuml;berschreiben"; break;
case "Guarda il file":                                                   $messaggio = "Zeige Datei"; break;
case "per salvarlo (eventualmente usa il bottone indietro del browser per tornare qui)":        $messaggio = "zur Sicherung ( nuten Sie den Browser \"zurck Button\" um zurckzugelangen"; break;
case "Cancella":                                                         $messaggio = "L&ouml;schen"; break;
case " l'attuale file di backup":                                        $messaggio = " aktuelle Datensicherungsdatei"; break;
case "Ripristina i dati dal file":                                       $messaggio = "Wiederherstellung der Daten von Datei"; break;
case " (i dati attuali verranno cancellati), utilizzando per la connessione al database:":        $messaggio = " (aktuelle Daten werden gel&ouml;scht), benutzen f&uuml;r Datenbankerzeugung:"; break;
case "i dati dell'attuale connessione":                                  $messaggio = "Daten der aktuellen Verbindung"; break;
case "nuovi dati":                                                       $messaggio = "neue Daten"; break;
case "Ho fatto l'upload del file":                                       $messaggio = "Sie haben die Datei hochgeladen"; break;
case "Non ho potuto fare l'upload del file":                             $messaggio = "Fehlschlag beim Hochladen der Datei"; break;
case "Fai l'upload":                                                     $messaggio = "Hochladen"; break;
case " del file di backup":                                              $messaggio = " diese Sicherungsdatei"; break;
case " di un nuovo file di backup":                                      $messaggio = " dieser neuen Sicherungsdatei"; break;
case "Prefisso nel nome delle tabelle":                                  $messaggio = "Prefix in Tabellenname"; break;
case "opzionale, utile per più installazioni di hoteldruid nello stesso database":	$messaggio = "optional, hilfreich f&uuml;r mehrere Installationen von Hoteldruid in der gleichen Datenbank"; break;
case "Il prefisso del nome delle tabelle è sbagliato (accettate solo lettere minuscole, numeri e _ , primo carattere lettera)":        $messaggio = "Das Prefix der Tabellennamen ist ung&uuml;ltig (nur Kleinbuchstaben, Nummern und _, das erste Zeichen mu&szlig; ein Buchstabe sein)"; break;
case "Il contenuto del file inviato non è corretto":                    $messaggio = "Der Inhalt der hochgeladenen Datei war fehlerhaft"; break;
case "Il formato del file è errato":                                    $messaggio = "Das Format der Datei war falsch"; break;
case "Compresso":                                                        $messaggio = "Komprimiert"; break;
case "Backup dei documenti":                                             $messaggio = "Dokumentensicherung"; break;
case "Crea il file di backup dei documenti":                             $messaggio = "Sicherung der Dokumente"; break;
case "Crea un nuovo file di backup dei documenti":                       $messaggio = "Erstellen einer neuen Dokumentensicherung"; break;
case " del file di backup dei documenti":                                $messaggio = " Backup dieser Dokumente"; break;
case " di un nuovo file di backup dei documenti":                        $messaggio = " neue Dokumente in diesem Backupsatz"; break;
case " l'attuale file di backup dei documenti":                          $messaggio = " aktuelle Dokumente in diesem Backupsatz"; break;
case "aggiungi ai documenti attuali":                                    $messaggio = "zum aktuellen Dokument hinzufgen"; break;
case "rimpiazza i documenti attuali":                                    $messaggio = "aktuelles Dokument ersetzen"; break;
case "i documenti attuali verranno cancellati":                          $messaggio = "aktuelles Dokument wird gelscht"; break;
case "Ripristina i documenti dal file":                                  $messaggio = "Dokument wiederherstellen"; break;
case "Documenti ripristinati":                                           $messaggio = "Documente wiederhergestellt"; break;
case "Backup completo":                                                  $messaggio = "Vollst&auml;ndige Sicherung"; break;
case "Includi i modelli internet":                                       $messaggio = "Vorlagen einschliessen"; break;
case "creato il":                                                        $messaggio = "erstellt"; break;
case "alle":                                                             $messaggio = "um"; break;
case "copia":                                                            $messaggio = "Kopie"; break;
case "il file di backup dai documenti predefiniti in":                   $messaggio = "Backupsatz der Standarddokumente aus"; break;
case "file copiato":                                                     $messaggio = "Dateine kopiert"; break;
case "si è verificato un errore copiando il file":                      $messaggio = "Es ist ein Fehler beim kopieren aufgetreten"; break;
case "Errori":  				                        $messaggio = "Fehler"; break;
case "Includi tutti gli anni":  		                        $messaggio = "Alle Jahre einschlie&szlig;en"; break;
case "Includi solo gli anni selezionati":  	                        $messaggio = "Nur die gew&auml;hlten Jahre einschlie&szlig;en"; break;
case "Prova a mantenere i dati degli anni non contenuti nel backup":	$messaggio = "Versuche Daten der Jahre zu behalten, die nicht in der Datensicherung enthalten sind"; break;
case "alcuni dati di questi anni potrebbero comunque venir persi":	$messaggio = "Einige Daten aus diesen Jahren k&ouml;nnen verloren worden sein"; break;
case "Normalmete 5432 o 5433 per Postgresql o 3306 per Mysql":	$messaggio = "Normally 5432 or 5433 for Postgresql or 3306 for Mysql"; break;
case "Sistema di backup per HotelDruid":  	$messaggio = "Backup system for HotelDruid"; break;
case "tutti i documenti contenuti nel file":	$messaggio = "all the documents contained in file"; break;
case "solo il documento":  			$messaggio = "only document"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
